@@ -45,8 +45,13 @@ async def query(
         if print_raw_results:
             debug(j)
     except edgedb.errors.ConstraintViolationError as e:
-        field_name = str(e).split(" ")[0].replace("_", " ")
-        raise ExecuteException(f"That {field_name} already exists in our system.")
+        print(f"{e=}")
+        if "is prohibited by link target policy" in str(e):
+            raise e
+        if "violates exclusivity constraint" in str(e):
+            field_name = str(e).split(" ")[0].replace("_", " ")
+            raise ExecuteException(f"That {field_name} already exists in our system.")
+        raise e
     except Exception as e:
         print(
             f"EdgeDB Query Exception: {e}, query_str and variables: {query_str=}, {variables=}"
