@@ -399,7 +399,7 @@ class Node(BaseModel, T.Generic[InsertType, PatchType]):
         upsert_given_conflict_on: str = None,
         return_conflicting_model_on: str = None,
         custom_on_conflict_str: str = None,
-    ) -> T.Set[ThisNodeType]:
+    ) -> T.List[ThisNodeType]:
         """This returns in no specific order"""
         if not given_resolver:
             given_resolver = cls.GraphORM.resolver_type()
@@ -450,7 +450,7 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
                 variables={"data": data_json},
             )
         with safe_span(op=f"parse.{cls._model_name}", description=f"{raw_d=}"):
-            return {given_resolver.parse_nested_obj(d) for d in raw_d}
+            return [given_resolver.parse_nested_obj(d) for d in raw_d]
 
     @classmethod
     async def add_many_old(
